Message

Struct Message 

#[non_exhaustive]
pub struct Message<P> { pub join_reference: Option<String>, pub message_reference: Option<String>, pub topic_name: String, pub event_name: String, pub payload: P, }
Message received from the channel.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
join_reference: Option<String>

The join_reference is also chosen by the client and should also be a unique value.

It only needs to be sent for a phx_join event; for other messages it can be null. It is used as a message reference for push messages from the server, meaning those that are not replies to a specific client message. For example, imagine something like “a new user just joined the chat room”.

message_reference: Option<String>

The message_reference is chosen by the client and should be a unique value.

The server includes it in its reply so that the client knows which message the reply is for.

topic_name: String

The topic_name must be a known topic for the socket endpoint, and a client must join that topic before sending any messages on it.

event_name: String

The event_name must match the first argument of a handle_in function on the server channel module.

payload: P

The payload should be a map and is passed as the second argument to that handle_in function.

Implementations

Source

impl Message<Value>

pub fn deserialize_payload<P>(self) -> Result<Message<P>, Error>

Deserialize the value in a specific payload type.

This makes it possible to match on the topic_name and event_name to differentiate the various responses.